import logging
from pathlib import Path

from pyannote.audio import Audio

logging.basicConfig(
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
    datefmt="%Y-%m-%d %H:%M:%S",
)

PROJECT_DIR = Path(__file__).parents[2]

AUDIO = Audio(sample_rate=16000, mono="downmix")
LOGGER = logging.getLogger(__name__.upper())
LOGGER.setLevel(logging.INFO)


def validate_kwargs(func):
    def inner(*args, **kwargs):
        argnames = func.__code__.co_varnames[: func.__code__.co_argcount]
        invalid_kwargs = [k for k in kwargs.keys() if k not in argnames]

        if len(invalid_kwargs) > 0:
            LOGGER.error(f"The arguments {invalid_kwargs} are not in the `{func.__name__}` function and thus ignored")
            for invalid in invalid_kwargs:
                kwargs.pop(invalid)

        return func(*args, **kwargs)

    return inner
